@@ -70,7 +70,28 @@ class NomadProvider(
         :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NomadProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                address: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                ca_file: typing.Optional[builtins.str] = None,
+                ca_pem: typing.Optional[builtins.str] = None,
+                cert_file: typing.Optional[builtins.str] = None,
+                cert_pem: typing.Optional[builtins.str] = None,
+                consul_token: typing.Optional[builtins.str] = None,
+                headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
+                http_auth: typing.Optional[builtins.str] = None,
+                ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
+                key_file: typing.Optional[builtins.str] = None,
+                key_pem: typing.Optional[builtins.str] = None,
+                region: typing.Optional[builtins.str] = None,
+                secret_id: typing.Optional[builtins.str] = None,
+                vault_token: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = NomadProviderConfig(
@@ -245,7 +266,9 @@ class NomadProvider(
     @address.setter
     def address(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "address").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "address", value)
 
@@ -257,7 +280,9 @@ class NomadProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -269,7 +294,9 @@ class NomadProvider(
     @ca_file.setter
     def ca_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "ca_file").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "caFile", value)
 
@@ -281,7 +308,9 @@ class NomadProvider(
     @ca_pem.setter
     def ca_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "ca_pem").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "caPem", value)
 
@@ -293,7 +322,9 @@ class NomadProvider(
     @cert_file.setter
     def cert_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "cert_file").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "certFile", value)
 
@@ -305,7 +336,9 @@ class NomadProvider(
     @cert_pem.setter
     def cert_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "cert_pem").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "certPem", value)
 
@@ -317,7 +350,9 @@ class NomadProvider(
     @consul_token.setter
     def consul_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "consul_token").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "consulToken", value)
 
@@ -334,7 +369,11 @@ class NomadProvider(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "headers").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List["NomadProviderHeaders"]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "headers", value)
 
@@ -346,7 +385,9 @@ class NomadProvider(
     @http_auth.setter
     def http_auth(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "http_auth").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "httpAuth", value)
 
@@ -363,7 +404,11 @@ class NomadProvider(
         value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "ignore_env_vars").fset)
+            def stub(
+                value: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ignoreEnvVars", value)
 
@@ -375,7 +420,9 @@ class NomadProvider(
     @key_file.setter
     def key_file(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "key_file").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyFile", value)
 
@@ -387,7 +434,9 @@ class NomadProvider(
     @key_pem.setter
     def key_pem(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "key_pem").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyPem", value)
 
@@ -399,7 +448,9 @@ class NomadProvider(
     @region.setter
     def region(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "region").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "region", value)
 
@@ -411,7 +462,9 @@ class NomadProvider(
     @secret_id.setter
     def secret_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "secret_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretId", value)
 
@@ -423,7 +476,9 @@ class NomadProvider(
     @vault_token.setter
     def vault_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NomadProvider, "vault_token").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vaultToken", value)
 
@@ -487,7 +542,26 @@ class NomadProviderConfig:
         :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NomadProviderConfig.__init__)
+            def stub(
+                *,
+                address: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                ca_file: typing.Optional[builtins.str] = None,
+                ca_pem: typing.Optional[builtins.str] = None,
+                cert_file: typing.Optional[builtins.str] = None,
+                cert_pem: typing.Optional[builtins.str] = None,
+                consul_token: typing.Optional[builtins.str] = None,
+                headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["NomadProviderHeaders", typing.Dict[str, typing.Any]]]]] = None,
+                http_auth: typing.Optional[builtins.str] = None,
+                ignore_env_vars: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, cdktf.IResolvable]]] = None,
+                key_file: typing.Optional[builtins.str] = None,
+                key_pem: typing.Optional[builtins.str] = None,
+                region: typing.Optional[builtins.str] = None,
+                secret_id: typing.Optional[builtins.str] = None,
+                vault_token: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument address", value=address, expected_type=type_hints["address"])
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument ca_file", value=ca_file, expected_type=type_hints["ca_file"])
@@ -699,7 +773,9 @@ class NomadProviderHeaders:
         :param value: The header value. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#value NomadProvider#value}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NomadProviderHeaders.__init__)
+            def stub(*, name: builtins.str, value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         self._values: typing.Dict[str, typing.Any] = {
