@@ -62,7 +62,24 @@ class QuotaSpecification(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecification.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                limits: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["QuotaSpecificationLimits", typing.Dict[str, typing.Any]]]],
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = QuotaSpecificationConfig(
@@ -90,7 +107,11 @@ class QuotaSpecification(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecification.put_limits)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["QuotaSpecificationLimits", typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putLimits", [value]))
 
@@ -146,7 +167,9 @@ class QuotaSpecification(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecification, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -158,7 +181,9 @@ class QuotaSpecification(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecification, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -170,7 +195,9 @@ class QuotaSpecification(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecification, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -224,7 +251,22 @@ class QuotaSpecificationConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                limits: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["QuotaSpecificationLimits", typing.Dict[str, typing.Any]]]],
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -391,7 +433,13 @@ class QuotaSpecificationLimits:
         if isinstance(region_limit, dict):
             region_limit = QuotaSpecificationLimitsRegionLimit(**region_limit)
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimits.__init__)
+            def stub(
+                *,
+                region: builtins.str,
+                region_limit: typing.Union["QuotaSpecificationLimitsRegionLimit", typing.Dict[str, typing.Any]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument region_limit", value=region_limit, expected_type=type_hints["region_limit"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -448,7 +496,13 @@ class QuotaSpecificationLimitsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimitsList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -460,7 +514,9 @@ class QuotaSpecificationLimitsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimitsList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("QuotaSpecificationLimitsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -473,7 +529,9 @@ class QuotaSpecificationLimitsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -486,7 +544,9 @@ class QuotaSpecificationLimitsList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -499,7 +559,9 @@ class QuotaSpecificationLimitsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -516,7 +578,11 @@ class QuotaSpecificationLimitsList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[QuotaSpecificationLimits]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[QuotaSpecificationLimits]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -540,7 +606,14 @@ class QuotaSpecificationLimitsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimitsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -587,7 +660,9 @@ class QuotaSpecificationLimitsOutputReference(
     @region.setter
     def region(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsOutputReference, "region").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "region", value)
 
@@ -604,7 +679,11 @@ class QuotaSpecificationLimitsOutputReference(
         value: typing.Optional[typing.Union[QuotaSpecificationLimits, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[QuotaSpecificationLimits, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -626,7 +705,13 @@ class QuotaSpecificationLimitsRegionLimit:
         :param memory_mb: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/quota_specification#memory_mb QuotaSpecification#memory_mb}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimitsRegionLimit.__init__)
+            def stub(
+                *,
+                cpu: typing.Optional[jsii.Number] = None,
+                memory_mb: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cpu", value=cpu, expected_type=type_hints["cpu"])
             check_type(argname="argument memory_mb", value=memory_mb, expected_type=type_hints["memory_mb"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -674,7 +759,12 @@ class QuotaSpecificationLimitsRegionLimitOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(QuotaSpecificationLimitsRegionLimitOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -705,7 +795,9 @@ class QuotaSpecificationLimitsRegionLimitOutputReference(
     @cpu.setter
     def cpu(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsRegionLimitOutputReference, "cpu").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpu", value)
 
@@ -717,7 +809,9 @@ class QuotaSpecificationLimitsRegionLimitOutputReference(
     @memory_mb.setter
     def memory_mb(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsRegionLimitOutputReference, "memory_mb").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryMb", value)
 
@@ -732,7 +826,11 @@ class QuotaSpecificationLimitsRegionLimitOutputReference(
         value: typing.Optional[QuotaSpecificationLimitsRegionLimit],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(QuotaSpecificationLimitsRegionLimitOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[QuotaSpecificationLimitsRegionLimit],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
